==> apache-hop-2.13.0-src.tar.gz: apache-hop-2.13.0/plugins/actions/deletefolders/src/test/java/org/apache/hop/workflow/actions/deletefolders/ActionDeleteFoldersTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.workflow.actions.deletefolders;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertFalse;

import org.apache.hop.core.logging.HopLogStore;
import org.apache.hop.workflow.action.ActionSerializationTestUtil;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;

public class ActionDeleteFoldersTest {

  @BeforeAll
  public static void setUpBeforeClass() {
    HopLogStore.init();
  }

  @Test
  void testNewSerialization() throws Exception {
    ActionDeleteFolders meta =
        ActionSerializationTestUtil.testSerialization(
            "/delete-folders-action.xml", ActionDeleteFolders.class);

    assertFalse(meta.isArgFromPrevious());
    assertEquals(
        ActionDeleteFolders.SuccessCondition.AT_LEAST_X_FOLDERS_DELETED,
        meta.getSuccessCondition());
    assertEquals("1", meta.getLimitFolders());
    assertEquals("C:\\folder", meta.getFileItems().get(0).getFileName());
    assertEquals(1, meta.getFileItems().size());
  }

  @Test
  public void testClone() throws Exception {
    ActionDeleteFolders meta =
        ActionSerializationTestUtil.testSerialization(
            "/delete-folders-action.xml", ActionDeleteFolders.class);

    ActionDeleteFolders clone = (ActionDeleteFolders) meta.clone();
    assertEquals(clone.getFileItems(), meta.getFileItems());
    assertEquals(clone.getSuccessCondition(), meta.getSuccessCondition());
    assertEquals(clone.isArgFromPrevious(), meta.isArgFromPrevious());
  }
}

==> apache-hop-2.15.0-src.tar.gz: apache-hop-2.15.0/plugins/actions/deletefolders/src/test/java/org/apache/hop/workflow/actions/deletefolders/ActionDeleteFoldersTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.workflow.actions.deletefolders;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertFalse;

import org.apache.hop.core.logging.HopLogStore;
import org.apache.hop.workflow.action.ActionSerializationTestUtil;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;

class ActionDeleteFoldersTest {

  @BeforeAll
  static void setUpBeforeClass() {
    HopLogStore.init();
  }

  @Test
  void testNewSerialization() throws Exception {
    ActionDeleteFolders meta =
        ActionSerializationTestUtil.testSerialization(
            "/delete-folders-action.xml", ActionDeleteFolders.class);

    assertFalse(meta.isArgFromPrevious());
    assertEquals(
        ActionDeleteFolders.SuccessCondition.AT_LEAST_X_FOLDERS_DELETED,
        meta.getSuccessCondition());
    assertEquals("1", meta.getLimitFolders());
    assertEquals("C:\\folder", meta.getFileItems().get(0).getFileName());
    assertEquals(1, meta.getFileItems().size());
  }

  @Test
  void testClone() throws Exception {
    ActionDeleteFolders meta =
        ActionSerializationTestUtil.testSerialization(
            "/delete-folders-action.xml", ActionDeleteFolders.class);

    ActionDeleteFolders clone = (ActionDeleteFolders) meta.clone();
    assertEquals(clone.getFileItems(), meta.getFileItems());
    assertEquals(clone.getSuccessCondition(), meta.getSuccessCondition());
    assertEquals(clone.isArgFromPrevious(), meta.isArgFromPrevious());
  }
}
